<?php
/**
* @version 			1.0.0
* @author       	http://www.seblod.com
* @copyright		Copyright (C) 2012 SEBLOD. All Rights Reserved.
* @license 			GNU General Public License version 2 or later; see _LICENSE.php
* @package			Tasks & WebServices for SEBLOD 1.x
**/

// No Direct Access
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport( 'joomla.application.component.controller' );

/**
 * Controller Class
 **/
class CCKjSeblod_WebServiceControllerJobs_Categories extends CCKjSeblod_WebServiceController
{
	var $_isAuth	=	null;
	var $_viewName	=	'job';
	var $_viewNames	=	'jobs';
	var $_viewTable	=	'jseblod_cck_webservices_jobs';
	var $_viewLink	=	_LINK_VIEW_3;
	
	/**
	 * Constructor
	 **/
	function __construct()
	{
		parent::__construct();
		
		// Register Extra Tasks
		$this->registerTask( 'add', 'edit' );
		$this->registerTask( 'apply', 'save' );
		$this->registerTask( 'copy', 'edit' );
		$this->registerTask( 'delete', 'edit' );
				
		// Check User Auth
		$user	=&	JFactory::getUser();
		$isAuth	=	( $user->get( 'gid' ) < _VIEW_ACCESS ) ? 0 : 1;
		$this->_setValues( $isAuth );
	}
	
	/**
	 * Set Values 
	 **/
	function _setValues( $isAuth )
	{
		// Set Values
		$this->_isAuth	=	$isAuth;
	}
	
	/**
	 * Display Default View
	 **/
	function display()
	{
		global $mainframe;
		
		// Check User Authorization
		if ( ! $this->_isAuth ) {
			$mainframe->redirect( _LINK_COMPONENT, JText::_( 'NOT AUTH' ), 'error' );
		}
		
		// Set Default View
		$view	=	JRequest::getCmd( 'view' );
		if ( empty( $view ) ) {
			JRequest::setVar( 'view', $this->_viewNames.'_categories' );
			JRequest::setVar( 'layout', 'default' );
		}
		
		parent::display();
	}
		
	/**
	 * Display Edit Form
	 **/
	function edit()
	{	
		global $mainframe;
		
		// Check User Authorization;
		if ( ! $this->_isAuth ) {
			$mainframe->redirect( _LINK_COMPONENT, JText::_( 'NOT AUTH' ), 'error' );
		}
		
		switch( $this->getTask() ) {
			case 'add':
			case 'edit':
				JRequest::setVar( 'view', $this->_viewNames.'_category' );
				JRequest::setVar( 'layout', 'form' );
				JRequest::setVar( 'hidemainmenu', 1 );
				JRequest::setVar( 'doCopy', false );
				JRequest::setVar( 'doDelete', false );
				break;
			case 'copy':
				JRequest::setVar( 'view', $this->_viewNames.'_category' );
				JRequest::setVar( 'layout', 'form' );
				JRequest::setVar( 'hidemainmenu', 1 );
				JRequest::setVar( 'doCopy', true );
				JRequest::setVar( 'doDelete', false );
				break;
			case 'delete':
				JRequest::setVar( 'view', $this->_viewNames.'_category' );
				JRequest::setVar( 'layout', 'delete' );
				JRequest::setVar( 'hidemainmenu', 1 );
				JRequest::setVar( 'doCopy', false );
				JRequest::setVar( 'doDelete', true );
				break;
			default:
				break;
		}
		
		parent::display();
	}

	/**
	 * Remove && Redirect
	 **/
	function remove()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$deleteMode	=	1;
		$model 		=	$this->getModel( $this->_viewNames.'_category' );
		
		if ( $model->cannotDelete() ) {
			$msg		=	JText::_( 'CANNOT REMOVE CATEGORY' );
			$msgType	=	'notice';
		} else {
			if ( $total	= $model->delete( $deleteMode ) ) {
				$msg		=	JText::sprintf( 'Items Removed', $total );
				$msgType	=	'message';
			} else {
				$msg		=	JText::_( 'An error has occurred' );
				$msgType	=	'error';
			}
		}
		
		$link	=	$this->_viewLink.'_categories';
		
		$this->setRedirect( $link, $msg, $msgType );
	}
	/**
	 * Remove && Redirect
	 **/
	function removeAll()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$deleteMode	=	-1;
		$model		=	$this->getModel( $this->_viewNames.'_category' );
		
		if ( $model->cannotDelete() ) {
			$msg		=	JText::_( 'CANNOT REMOVE CATEGORY' );
			$msgType	=	'notice';
		} else {
			if ( $total	= $model->delete( $deleteMode ) ) {
				$msg		=	JText::sprintf( 'Items Removed', $total );
				$msgType	=	'message';
			} else {
				$msg		=	JText::_( 'An error has occurred' );
				$msgType	=	'error';
			}
		}
		
		$link	=	$this->_viewLink.'_categories';
		
		$this->setRedirect( $link, $msg, $msgType );
	}

	/**
	 * Publish && Redirect
	 **/
	function publish()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$model	=	$this->getModel( $this->_viewNames.'_category' );
		
		$cid	=	JRequest::getVar( 'cid', array(), 'post', 'array' );
		JArrayHelper::toInteger( $cid );
		if ( count( $cid ) < 1 ) {
			JError::raiseError( 500, JText::_( 'Select an Item to publish' ) );
		}
		
		if ( ! $model->publish( $cid, 1 ) ) {
			echo "<script> alert('".$model->getError( true )."'); window.history.go(-1); </script>\n";
		}
		
		$link	=	$this->_viewLink.'_categories';
		
		$this->setRedirect( $link );
	}
	
	/**
	 * Unpublish && Redirect
	 **/
	function unpublish()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$model	=	$this->getModel( $this->_viewNames.'_category' );
		
		$cid	=	JRequest::getVar( 'cid', array(), 'post', 'array' );
		JArrayHelper::toInteger( $cid );
		if ( count( $cid ) < 1 ) {
			JError::raiseError( 500, JText::_( 'Select an Item to unpublish' ) );
		}
		
		if ( ! $model->publish( $cid, 0 ) ) {
			echo "<script> alert('".$model->getError( true )."'); window.history.go(-1); </script>\n";
		}
		
		$link	=	$this->_viewLink.'_categories';
		
		$this->setRedirect( $link );
	}
	
	/**
	 * Back
	 **/
	function back()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$link	=	$this->_viewLink;
		
		$this->setRedirect( $link );
	}

	/**
	 * Save && Redirect
	 **/
	function save()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$model	=	$this->getModel( $this->_viewNames.'_category' );
		
		if ( $rowId = $model->store() ) {
			$msg		=	JText::_( 'Item Saved' );
			$msgType	=	'message';
		} else {
			$msg		=	JText::_( 'An error has occurred' );
			$msgType	=	'error';
		}
		
		// Checkin!
		$model->checkin();
		
		switch( $this->getTask() ) {
			case 'apply':
				$link	=	( $rowId ) ? $this->_viewLink.'_categories'.'&task=edit&cid[]='.$rowId : $this->_viewLink.'_categories';
				break;
			case 'save':
				$link	=	$this->_viewLink.'_categories';
				break;
			default:
				break;
		}
		
		$this->setRedirect( $link, $msg, $msgType );
	}
	
	/**
	 * Live Save && Redirect
	 **/
	function liveSave()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$model	=	$this->getModel( $this->_viewNames.'_category' );
		
		if ( $rowId = $model->liveStore() ) {
		}
		
		$link	=	$this->_viewLink.'_categories';
		
		$this->setRedirect( $link );
	}
	
	/**
	 * Cancel && Redirect
	 **/
	function cancel()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$model	=	$this->getModel( $this->_viewNames.'_category' );
		
		// Checkin!
		$model->checkin();
		
		$link	=	$this->_viewLink.'_categories';
		
		$this->setRedirect( $link );
	}

	/**
	 * Check Availability [ Ajax ]
	 **/
	function checkAvailability()
	{
		$available	=	0;
		$total		=	0;
		
		if ( $available = JRequest::getVar( 'available', '', 'get', 'string' ) ) {
			
			// Check Name
			$available	=	Helper_Helper::stringURLSafe( $available );
			if( trim( str_replace( '_', '', $available ) ) == '' ) {
				$datenow	=&	JFactory::getDate();
				$available	=	$datenow->toFormat( "%Y_%m_%d_%H_%M_%S" );
			}
			
			$db	=& JFactory::getDBO();
			$where 		= ' WHERE s.name = "'.$available.'"';
			
			$query = ' SELECT COUNT( s.id )'
				   . ' FROM #__'.$this->_viewTable.'_categories AS s'
				   . $where
				   ;
			$db->setQuery( $query );
			$total	=	$db->loadResult();
		} 
		
		echo $total;
	}
	
}
?>