<?php
/**
* @version 			1.0.0
* @author       	http://www.seblod.com
* @copyright		Copyright (C) 2012 SEBLOD. All Rights Reserved.
* @license 			GNU General Public License version 2 or later; see _LICENSE.php
* @package			Tasks & WebServices for SEBLOD 1.x
**/

// No Direct Access
defined( '_JEXEC' ) or die( 'Restricted access' );

jimport( 'joomla.application.component.controller' );

/**
 * Controller Class
 **/
class CCKjSeblod_WebServiceControllerWebServices extends CCKjSeblod_WebServiceController
{
	var $_isAuth	=	null;
	var $_viewName	=	'webservice';
	var $_viewNames	=	'webservices';
	var $_viewTable	=	'jseblod_cck_webservices';
	
	/**
	 * Constructor
	 **/
	function __construct()
	{
		parent::__construct();
		
		// Register Extra Tasks
		$this->registerTask( 'add', 'edit' );
		$this->registerTask( 'copy', 'edit' );
		$this->registerTask( 'apply', 'save' );
		$this->registerTask( 'delete', 'edit' );
		
		// Check User Auth
		$user 	=&	JFactory::getUser();
		$isAuth	=	( $user->get( 'gid' ) < _VIEW_ACCESS ) ? 0 : 1;
		$this->_setValues( $isAuth );
	}
	
	/**
	 * Set Values 
	 **/
	function _setValues( $isAuth )
	{
		// Set Values
		$this->_isAuth	= $isAuth;
	}
	
	/**
	 * Display Default View
	 **/
	function display()
	{
		global $mainframe;
		
		// Check User Authorization
		if ( ! $this->_isAuth ) {
			$mainframe->redirect( _LINK_COMPONENT, JText::_( 'Alertnotauth' ), 'error' );
		}
		
		switch( $this->getTask() ) {
			case 'element':
				JRequest::setVar( 'view', $this->_viewNames );
				JRequest::setVar( 'layout', 'element' );
				break;
			case 'select':
				JRequest::setVar( 'view', $this->_viewNames );
				JRequest::setVar( 'layout', 'select' );
				break;
			default:
				// Set Default View
				$view	=	JRequest::getCmd( 'view' );
				if ( empty( $view ) ) {
					JRequest::setVar( 'view', $this->_viewNames );
					JRequest::setVar( 'layout', 'default' );
				}
				break;
		}
			
		parent::display();
	}
	
	/**
	 * Display Edit Form
	 **/
	function edit()
	{
		global $mainframe;
		
		// Check User Authorization;
		if ( ! $this->_isAuth ) {
			$mainframe->redirect( _LINK_COMPONENT, JText::_( 'Alertnotauth' ), 'error' );
		}
		
		switch( $this->getTask() ) {
			case 'add':
			case 'edit':
				JRequest::setVar( 'view', $this->_viewName );
				JRequest::setVar( 'layout', 'form' );
				JRequest::setVar( 'hidemainmenu', 1 );
				JRequest::setVar( 'doCopy', false );
				JRequest::setVar( 'doDelete', false );
				JRequest::setVar( 'doSource', false );
				break;
			case 'copy':
				JRequest::setVar( 'view', $this->_viewName );
				JRequest::setVar( 'layout', 'form' );
				JRequest::setVar( 'hidemainmenu', 1 );
				JRequest::setVar( 'doCopy', true );
				JRequest::setVar( 'doDelete', false );
				JRequest::setVar( 'doSource', false );
				break;
			case 'delete':
				JRequest::setVar( 'view', $this->_viewName );
				JRequest::setVar( 'layout', 'delete' );
				JRequest::setVar( 'hidemainmenu', 1 );
				JRequest::setVar( 'doCopy', false );
				JRequest::setVar( 'doDelete', true );
				JRequest::setVar( 'doSource', false );
				break;
			default:
				break;
		}
		
		parent::display();
	}
	
	/**
	 * Remove &&  Redirect
	 **/
	function remove()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$deleteMode	=	1;
		$model		=	$this->getModel( $this->_viewName );
		
		if ( $total = $model->delete( $deleteMode ) ) {
			$msg		=	JText::sprintf( 'Items Removed', $total );
			$msgType	=	'message';
		} else {
			$msg		=	JText::_( 'An error has occurred' );
			$msgType	=	'error';
		}
		
		$link	=	_LINK_VIEW_1;
		
		$this->setRedirect( $link, $msg, $msgType );
	}

	/**
	 * Remove && Redirect
	 **/
	function removeAll()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$deleteMode	=	-1;
		$model = $this->getModel( $this->_viewName );
		
		if ( $total = $model->delete( $deleteMode ) ) {
			$msg		=	JText::sprintf( 'Items Removed', $total );
			$msgType	=	'message';
		} else {
			$msg		=	JText::_( 'An error has occurred' );
			$msgType	=	'error';
		}
		$link	=	_LINK_VIEW_1;
		
		$this->setRedirect( $link, $msg, $msgType );
	}

	/**
	 * Publish && Redirect
	 **/
	function publish()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$model	=	$this->getModel( $this->_viewName );
		
		$cid	=	JRequest::getVar( 'cid', array(), 'post', 'array' );
		JArrayHelper::toInteger( $cid );

		if ( count( $cid ) < 1 ) {
			JError::raiseError( 500, JText::_( 'Select an Item to publish' ) );
		}

		if ( ! $model->publish( $cid, 1 ) ) {
			echo "<script> alert('".$model->getError(true)."'); window.history.go(-1); </script>\n";
		}

		$link	=	_LINK_VIEW_1;
		
		$this->setRedirect( $link );
	}
	
	/**
	 * Unpublish && Redirect
	 **/
	function unpublish()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$model	=	$this->getModel( $this->_viewName );

		$cid	=	JRequest::getVar( 'cid', array(), 'post', 'array' );
		JArrayHelper::toInteger( $cid );

		if ( count( $cid ) < 1 ) {
			JError::raiseError( 500, JText::_( 'Select an Item to unpublish' ) );
		}

		if( ! $model->publish( $cid, 0 ) ) {
			echo "<script> alert('".$model->getError( true )."'); window.history.go(-1); </script>\n";
		}

		$link	=	_LINK_VIEW_1;
		
		$this->setRedirect( $link );
	}
		
	/**
	 * Categories Redirection
	 **/
	function categories()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$link	=	_LINK_VIEW_1.'_categories';
		
		$this->setRedirect( $link );
	}
	
	/**
	 * Add Category Redirection
	 **/
	function addcategory()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$link	=	_LINK_VIEW_1.'_categories'.'&task=add';
		
		$this->setRedirect( $link );
	}
	
	/**
	 * Batch Category Process
	 **/
	function batchCategory()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
				
		$model	=	$this->getModel( $this->_viewName );

		if ( $total = $model->batchCategory() ) {
			$msg		=	JText::sprintf( 'ITEMS UPDATED', $total );
			$msgType	=	'message';
		} else {
			$msg		=	JText::_( 'An error has occurred' );
			$msgType	=	'error';
		}
		
		$link	=	_LINK_VIEW_1;
		
		$this->setRedirect( $link, $msg, $msgType );
	}
	
	/**
	 * Save && Redirect
	 **/
	function save()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$model	=	$this->getModel( $this->_viewName );

		if ( $rowId = $model->store() ) {
			$msg		=	JText::_( 'Item Saved' );
			$msgType	=	'message';
		} else {
			$msg 		=	JText::_( 'An error has occurred' );
			$msgType	=	'error';
		}
		
		// Checkin!
		$model->checkin();
		
		switch( $this->getTask() ) {
			case 'apply':
				$link	=	( $rowId ) ? _LINK_VIEW_1.'&task=edit&cid[]='.$rowId : _LINK_VIEW_1;
				break;
			case 'save':
				$link	=	_LINK_VIEW_1;
				break;
			default:
				break;
		}
		
		$this->setRedirect( $link, $msg, $msgType );
	}
	
	/**
	 * Live Save && Redirect
	 **/
	function liveSave()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$model	=	$this->getModel( $this->_viewName );
		
		if ( $rowId = $model->liveStore() ) {
		}
		
		$link = _LINK_VIEW_1;
		
		$this->setRedirect( $link );
	}
	
	/**
	 * Cancel && Redirect
	 **/ 
	function cancel()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$model	=	$this->getModel( $this->_viewName );
		
		// Checkin!
		$model->checkin();
		
		$link	=	_LINK_VIEW_1;
		
		$this->setRedirect( $link );
	}
		
	/**
	 * Back
	 **/
	function back()
	{
		// Check for Request Forgeries
		JRequest::checkToken() or die( 'Invalid Token' );
		
		$link	=	_LINK_VIEW_1;
		
		$this->setRedirect( $link );
	}
	
	/**
	 * Check Availability [ Ajax ]
	 **/
	function checkAvailability()
	{
		$available	=	0;
		$total		=	0;
		
		if ( $available = JRequest::getVar( 'available', '', 'get', 'string' ) ) {
			if ( $available == 'class' ) {
				$total	=	1;
			} else {
				$db		=&	JFactory::getDBO();
				$where 	=	' WHERE s.name = "'.$available.'"';
				
				$query = ' SELECT COUNT( s.id )'
					   . ' FROM #__'.$this->_viewTable.' AS s'
					   . $where
					   ;
				$db->setQuery( $query );
				$total	=	$db->loadResult();
			}
		} 
		
		echo $total;
	}
}
?>